aboutsummaryrefslogtreecommitdiff
path: root/bin/sbotools-update-db.sh
diff options
context:
space:
mode:
Diffstat (limited to 'bin/sbotools-update-db.sh')
-rwxr-xr-xbin/sbotools-update-db.sh13
1 files changed, 7 insertions, 6 deletions
diff --git a/bin/sbotools-update-db.sh b/bin/sbotools-update-db.sh
index ec6a22f..90f4be3 100755
--- a/bin/sbotools-update-db.sh
+++ b/bin/sbotools-update-db.sh
@@ -2,16 +2,17 @@
# update the SBoTools.sqlite3 for the SBoTools limnoria plugin.
# should be run from cron probably daily. also can be run manually.
# run this as the slackfacts user, not root.
# configurables:
-BOTDIR=/home/slackfacts/supybot
+HOMEDIR=/home/ibob
+BOTDIR=$HOMEDIR/bot
DBFILE=$BOTDIR/SBoTools.sqlite3
-SCRIPT=$BOTDIR/limnoria.slackfacts.plugins/bin/sbodb.pl
-SBOTREE=/data/mirrors/slackbuilds.org/15.0
+SCRIPT=$HOMEDIR/bot-plugins/limnoria.slackfacts.plugins/bin/sbodb.pl
+SBOTREE=/data/depository/sbo/15.0
SQLITE3=/usr/bin/sqlite3
-LOG=$BOTDIR/sbotools-update-db.log
-DATEFILE=$BOTDIR/sbotools-update-db.lastdate
+LOG=$BOTDIR/logs/plugins/sbotools-update-db.log
+DATEFILE=$BOTDIR/SBoTools.lastdate
# 1st line of ChangeLog.txt is the date of the last SBo update.
head -n 1 $SBOTREE/ChangeLog.txt > $DATEFILE.new
@@ -2,16 +2,17 @@
# update the SBoTools.sqlite3 for the SBoTools limnoria plugin.
# should be run from cron probably daily. also can be run manually.
-# run this as the slackfacts user, not root.
+# run this as the ibob user, not root.
# configurables: